
module Hoogle.Score.All(
    module Hoogle.Score.Scoring,
    Score, TypeCost(..), TextMatch(..), textScore, typeScore, scoreCosts, cost
    ) where

import Hoogle.Score.Scoring
import Hoogle.Score.Type
